@@ -3,12 +3,12 @@ import json
 from oneparams.api.base_diff import BaseDiff
 from oneparams.api.perfils import Perfil
 from oneparams.api.profissao import Profissao
-from oneparams.utils import create_cel, create_email
+from oneparams.utils import create_email, deemphasize
 
 
-class Colaboradores(BaseDiff):
-    items = []
-    list_details = []
+class ApiColaboradores(BaseDiff):
+    items = {}
+    list_details = {}
     first_get = False
 
     def __init__(self):
@@ -27,49 +27,69 @@ class Colaboradores(BaseDiff):
                 "perfilId": Perfil()
             })
 
-        if not Colaboradores.first_get:
+        if not ApiColaboradores.first_get:
             self.get_all()
-            Colaboradores.first_get = True
+            ApiColaboradores.first_get = True
 
     def get_all(self):
         content = super().get_all()
-        Colaboradores.items = []
+        ApiColaboradores.items = {}
         for i in content:
-            Colaboradores.items.append({
-                "colaboradorId": i["cliForColsId"],
-                "nomeCompleto": i["nomeCompleto"],
-                "email": i["email"]
-            })
+            ApiColaboradores.items[i["cliForColsId"]] = {
+                self.key_id: i["cliForColsId"],
+                self.key_active: i[self.key_active],
+                self.key_name: i[self.key_name],
+                "email": i["email"],
+                "celular": i["celular"]
+            }
+
+    def add_item(self, data: dict, response: dict) -> int:
+        id = response["data"][self.key_id]
+        data = {
+            self.key_id: id,
+            self.key_active: data[self.key_active],
+            self.key_name: data[self.key_name],
+            "email": data["email"],
+            "celular": data["celular"]
+        }
+        self.items[id] = data
+        return id
 
     def get_sheduler(self):
         response = self.get("/OProfissional/ProfissionaisAgendaveis")
         self.status_ok(response)
         return json.loads(response.content)
 
-    def equals(self, data):
+    def equals(self, data: dict) -> bool:
         if data["email"] is None:
             data.pop("email")
         if data["celular"] is None:
             data.pop("celular")
         return super().equals(data)
 
-    def create(self, data):
+    def create(self, data: dict) -> int:
         if data["email"] is None:
             data["email"] = create_email()
         if data["celular"] is None:
-            data["celular"] = create_cel()
+            data["celular"] = "00000000"
         super().create(data)
 
-    def update(self, data):
+    def update(self, data: dict):
         if "email" not in data.keys():
             data["email"] = self.details(data[self.key_id])["email"]
         if "celular" not in data.keys():
             data["celular"] = self.details(data[self.key_id])["celular"]
         return super().update(data)
 
-    def item_id(self, data):
-        for i in self.items:
-            if (i[self.key_name] == data[self.key_name]
-                    or i["email"] == data["email"]):
-                return i[self.key_id]
+    def item_id(self, data: dict) -> int:
+        name = deemphasize(data[self.key_name])
+        email = deemphasize(data["email"])
+
+        for key, item in self.items.items():
+            existent_name = deemphasize(item[self.key_name])
+            existent_email = deemphasize(item["email"])
+
+            if (existent_name == name
+                    or existent_email == email):
+                return key
         return 0
