@@ -2,13 +2,13 @@ from oneparams.api.base_diff import BaseDiff
 from oneparams.api.gservs import Gservis
 
 
-class Servicos(BaseDiff):
+class ApiServicos(BaseDiff):
     """
     Gerenciamento de serviços,
     cria, atualiza, deleta e inativa serviços
     """
-    items = []
-    list_details = []
+    items = {}
+    list_details = {}
     first_get = False
 
     def __init__(self):
@@ -26,9 +26,26 @@ class Servicos(BaseDiff):
             key_active="flagAtivo",
             submodules={"gservId": Gservis()})
 
-        if not Servicos.first_get:
+        if not ApiServicos.first_get:
             self.get_all()
-            Servicos.first_get = True
+            ApiServicos.first_get = True
 
     def get_all(self):
-        Servicos.items = super().get_all()
+        items = super().get_all()
+        ApiServicos.items = {}
+        for i in items:
+            self.items[i[self.key_id]] = {
+                self.key_id: i[self.key_id],
+                self.key_name: i[self.key_name],
+                self.key_active: i[self.key_active]
+            }
+
+    def add_item(self, data: dict, response: dict) -> int:
+        id = response[self.key_id]
+        data = {
+            self.key_id: id,
+            self.key_name: data[self.key_name],
+            self.key_active: data[self.key_active]
+        }
+        ApiServicos.items[id] = data
+        return id
