@@ -1,18 +1,28 @@
 from oneparams.api.gservs import Gservis
-from oneparams.api.servicos import Servicos
+from oneparams.api.servicos import ApiServicos
 from oneparams.excel.excel import Excel
-from oneparams.utils import deemphasize
 
 
 def servico(book, reset=False):
+    """
+    Book: planilha com todos os dados \n
+    reset: True se todos os serviços do sistema
+    serão excluídos para cadastrar os serviços da planilha \n
+
+    Nessa função tem toda a descrição do json que vai ser enviado
+    para as rotas de cadastro do sistema
+
+    Return None
+    """
+    one = ApiServicos()
     print("analyzing spreadsheet")
 
     ex = Excel(book, "servico")
 
     ex.add_column(key="flagAtivo", name="ativo", required=False, default=True)
-    ex.add_column(key="descricao", name="nome")
+    ex.add_column(key="descricao", name="nome", length=50)
     ex.add_column(key="gservId", name="grupo")
-    ex.add_column(key="preco", name="valor", default=0, types="float")
+    ex.add_column(key="preco", name="valor", default=1, types="float")
     ex.add_column(key="comissao", name="comissao", default=0, types="float")
     ex.add_column(key="tempoExecucao",
                   name="execucao",
@@ -34,7 +44,7 @@ def servico(book, reset=False):
                   default=True,
                   types="bool")
     ex.add_column(key="permiteSimultaneidade",
-                  name="simultaniedade",
+                  name="simultaneidade",
                   required=False,
                   default=True,
                   types="bool")
@@ -48,7 +58,6 @@ def servico(book, reset=False):
                   default="P")
     ex.clean_columns()
 
-    one = Servicos()
     data = ex.data_all(check_row=checks, check_final=check_all)
 
     if reset:
@@ -58,20 +67,26 @@ def servico(book, reset=False):
         one.diff_item(row)
 
     grupo = Gservis()
-    grupo.all_Gservis()
+    grupo.get_all()
     grupo.clear()
 
 
 def checks(row, data):
+    """
+    row: linha da planilha \n
+    data: dados da linha da planilha \n
+
+    verificações especificas de serviços,
+    isso linha a linha, de forma individual
+
+    return data \n
+    raise Exception: caso ocorra algum erro durante
+    as verificações \n
+    """
     erros = False
     if data["descricao"] is None:
         print(f'ERROR! in line {row}: empty name')
         erros = True
-    if len(data["descricao"]) > 50:
-        print(
-            f'ERROR! in line {row}: Service {data["descricao"]} name size {len(data["descricao"])}/50'
-        )
-        erros = True
     if data["gservId"] is None:
         print(
             f'ERROR! in line {row}: Service {data["descricao"]} have empty group'
@@ -85,11 +100,22 @@ def checks(row, data):
     if erros:
         raise Exception
 
-    one = Servicos()
-    return one.name_to_id(data)
+    return data
 
 
 def check_all(self, data):
+    """
+    self: referencia da classe excel \n
+    data: data frame com todos os dados da planilha \n
+
+    Verificações 'globais', que necessitam de todos os
+    dados da planilha, principalmente duplicações
+
+    return data \n
+    raise Exception: caso tenha algum erro durante as
+    verificações \n
+
+    """
     erros = False
     duplic = data[data.duplicated(keep=False, subset=["descricao"])]
     for i in duplic.index:
