@@ -3,6 +3,7 @@ import re
 import string
 import unicodedata
 from difflib import SequenceMatcher
+import oneparams.config as config
 
 
 def deemphasize(word):
@@ -12,11 +13,19 @@ def deemphasize(word):
     """
     if word is None:
         return word
+    word = str(word)
     nfkd = unicodedata.normalize('NFKD', word)
     word = u"".join([c for c in nfkd if not unicodedata.combining(c)])
     return word.lower()
 
 
+def no_space(word):
+    """
+    Remove espaços em branco de uma string
+    """
+    return re.sub(r' ', '', word)
+
+
 def string_normalize(word):
     """
     Retorna todos as letras e números de uma string
@@ -97,7 +106,7 @@ def get_cel(word):
     if len(cel) <= 11 and len(cel) >= 8:
         return cel
 
-    raise ValueError("invalid phone {}".format(word))
+    raise ValueError("Invalid phone {}".format(word))
 
 
 def create_email():
@@ -111,6 +120,15 @@ def create_email():
     return f'one_{rand}@onebeleza.com'
 
 
+def check_email(email):
+    if email is None:
+        return False
+    r = re.compile(r'^[\w\.-]+@(?:[a-zA-Z0-9-]+\.)+[a-zA-Z]{2,}$',
+                   flags=re.ASCII)
+    email = no_space(email)
+    return r.search(email) is not None
+
+
 def create_cel():
     """
     Cria uma string de 11 dígitos aleatórios
@@ -164,3 +182,13 @@ def get_bool(value):
 
 def similar(word, word_diff):
     return SequenceMatcher(None, word, word_diff).ratio()
+
+
+def eprint(text):
+    if not config.RESOLVE_ERROS:
+        print(text)
+
+
+def wprint(text):
+    if not config.NO_WARNING:
+        print(text)
